@@ -260,7 +260,7 @@ class DoubleRatchet(ABC):
             The internal state of this :class:`DoubleRatchet` as a JSON-serializable Python object.
         """
 
-        return cast(JSONObject, json.loads(self.model.json()))
+        return cast(JSONObject, json.loads(self.model.model_dump_json()))
 
     @classmethod
     def from_model(
